@@ -497,14 +497,17 @@ def convert_to_occurrence(datas):
         vobj = load(d)
         vdetails = vobj["details"]
         package_type = ""
+        package = ""
         cpe_uri = ""
         if isinstance(vdetails, dict):
             package_type = vdetails["package_type"]
+            package = vdetails["package"]
             cpe_uri = vdetails["cpe_uri"]
         else:
             package_type = vdetails.package_type
+            package = vdetails.package
             cpe_uri = vdetails.cpe_uri
-        unique_key = vobj["id"] + "|" + cpe_uri
+        unique_key = vobj["id"] + "|" + package
         # Filter duplicates for the same package with the same id
         if unique_key not in id_list:
             occ = VulnerabilityOccurrence(
